/// <reference types="node" />
import * as AWS from 'aws-sdk';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { ISESHelper } from './interface';
/**
 * SES Helper
 */
export declare class SESHelper extends BaseClass implements ISESHelper {
    /**
     * AWS Repository for SES
     */
    Repository: AWS.SES;
    /**
     * Initializes new instance of SESHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SES} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SES.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.SES, options?: AWS.SES.ClientConfiguration);
    /**
     * Send an email
     * @param subject {string} Subject of email
     * @param toAddresses {string[]} Array of addresses to send to
     * @param fromAddress {string} Address to send from
     * @param body {string | Buffer} HTML body of message
     */
    SendEmailAsync(subject: string, toAddresses: string[], fromAddress: string, body: string | Buffer): Promise<AWS.SES.SendEmailResponse>;
}
