"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const mock_1 = require("./mock");
const test_values_1 = require("./test-values");
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const mockerResolves = new mock_1.SESMock(false);
const sesHelperMockResolves = new helper_1.SESHelper(logger, mockerResolves.Mock);
const mockerRejects = new mock_1.SESMock(true);
const sesHelperMockRejects = new helper_1.SESHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestingValues();
/**
 * Test the SendEmailAsync method
 */
describe(`${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.EmptyString, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, TestValues.EmptyArray, TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} toAddresses`);
    });
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = sesHelperMockRejects.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).resolves.toEqual(mockerResolves.SendEmailResponse);
    });
});
//# sourceMappingURL=helper.spec.js.map